#
# spec file for package python-passlib
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-passlib
Version:        1.7.1
Release:        lp150.1.4
Url:            https://bitbucket.org/ecollins/passlib
Summary:        Comprehensive password hashing framework supporting over 20 schemes
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/p/passlib/passlib-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# test requirements
BuildRequires:  %{python_module nose}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Passlib is a password hashing library for Python 2 & 3,
which provides cross-platform implementations of over 20
password hashing algorithms, as well as a framework for
managing existing password hashes. It's designed to be useful
for a wide range of tasks; from verifying a hash found in /etc/shadow,
to providing full-strength password hashing for multi-user applications.

%prep
%setup -q -n passlib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
%python_expand nosetests-%{$python_version} -v

%files %{python_files}
%defattr(-,root,root)
%doc LICENSE README
%{python_sitelib}/passlib
%{python_sitelib}/passlib-%{version}-py%{python_version}.egg-info

%changelog
* Sat Apr 22 2017 aloisio@gmx.com
- Converted to single-spec
- Enabled tests
* Tue Jan 31 2017 michael@stroeder.com
- Update to 1.7.1
* Sun Jan 22 2017 michael@stroeder.com
- updated project and source URLs
* Sat Nov 26 2016 michael@stroeder.com
- Update to 1.7.0 with very many changes:
  http://passlib.readthedocs.io/en/stable/history/1.7.html#id1
- CHANGES not in upstream source anymore
* Sun Feb 21 2016 mardnh@gmx.de
- Update to 1.6.5:
  * Fixed some minor bugs in the test suite which were causing erroneous
    test failures
- Update to 1.6.4:
  * bugfix: Correctly detect bcrypt 2.0.
  * bugfix: CryptContext now accepts scheme names as unicode
  * bugfix: :mod:`passlib.ext.django` now works correctly with Django 1.7-1.8.
  * bugfix: :class:`passlib.apache.HtpasswdFile` now recognizes bcrypt,
    sha256_crypt, sha512_crypt hashes
  * A few changes have been made to the :class:`~passlib.hash.bcrypt` hash:
    + It now supports the ``$2b$`` hash format.
    + It will now issue a :exc:`~passlib.exc.PasslibSecurityWarning` if the active
    backend is vulnerable to the :ref:`wraparound bug <bsd-wraparound-bug>`,
    and automatically enable a workaround(py-bcrypt is known to be vulnerableas of v0.4).
    + It will throw a :exc:`~passlib.exc.PasslibSecurityError` if the active backend
    is vulnerable to the :ref:`8-bit bug <crypt-blowfish-bug>` (none of Passlib's
    backends are known to be vulnerable as of 2015-07).
    + Updated documentation to indicate the cffi-based
    `bcrypt <https://pypi.python.org/pypi/bcrypt>`_ library is now the recommended
    bcrypt backend.
    + Backend capability detection code refactored to rely on runtime detection
    rather than hardcoded information.
    + Release **1.6.3** was skipped due to upload issues.
* Mon Jan 13 2014 dmueller@suse.com
- update to 1.6.2:
  * Re-tuned the :attr:`~passlib.ifc.PasswordHash.default_rounds` values for all of the hashes.
  * Added the new :doc:`bcrypt_sha256 <lib/passlib.hash.bcrypt_sha256>` hash,
  which wraps BCrypt using SHA256 in order to work around BCrypt's password size limitations
  * :doc:`passlib.hash.bcrypt <lib/passlib.hash.bcrypt>`:
  Added support for the `bcrypt <https://pypi.python.org/pypi/bcrypt>`_
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Feb  5 2013 saschpe@suse.de
- Drop testsuite again, has strange issues
* Sat Sep  8 2012 os-dev@jacraig.com
- Update to 1.6.1:
  * bugfix: Various CryptContext methods would incorrectly raise TypeError
    if passed a unicode user category under Python 2. For consistency,
    unicode user category values are now encoded to ``utf-8`` bytes under
    Python 2.
  * bugfix: Reworked internals of the CryptContext config compiler to fix a
    couple of border cases (issue 39), see CHANGES for details.
  * bugfix: FreeBSD 8.3 added native support for hash.sha256_crypt -- updated
    Passlib's unittests and documentation accordingly (issue 35).
  * bugfix: Fixed bug which caused passlib.apache unittest to fail if mtime
    resolution >= 1 second (issue 35).
  * Various bugfixes for Python 3.3 compatibility.
  * Various documentation updates and corrections.
* Fri Jun 15 2012 os-dev@jacraig.com
- Update to 1.6: tons of changes including deprecated API, features and fixes;
  see CHANGES.
* Thu Mar  8 2012 saschpe@suse.de
- Don't run testsuite on SLE, fixes build
* Tue Jan 31 2012 saschpe@suse.de
- Fix macro usage and remove reST from description
* Tue Nov 29 2011 saschpe@suse.de
- SPDX-style license string (BSD-3-Clause)
- Package CHANGES, README, LICENSE
- Run testsuite
* Mon Oct 24 2011 cthiel@suse.com
- initial package  (version 1.5.3)
